@@ -19,6 +19,7 @@
 #' 
 #' @inheritParams pscrub_Params
 #' @param projection One of the following: \code{"ICA"} (default) or \code{"PCA"}.
+#  or \code{"fusedPCA"}.
 # @param R_true The \eqn{T} by \eqn{T} correlation matrix, if known. Used for the bootstrap
 #  robust distance measure.
 #' @param PESEL Use \code{\link[pesel]{pesel}} to select the number of 
@@ -79,22 +80,31 @@
 #' @export
 #'
 #' @examples
-#' if (requireNamespace("fastICA", quietly = TRUE)) {
-#'  n_voxels = 5e3
-#'  n_timepoints = 70
-#'  X = matrix(rnorm(n_timepoints*n_voxels), ncol = n_voxels)
-#'  psx = pscrub(X)
-#' }
+#' library(fastICA)
+#' n_voxels = 2e3
+#' n_timepoints = 35
+#' X = matrix(rnorm(n_timepoints*n_voxels), ncol = n_voxels)
+#'
+#' psx = pscrub(X)
 pscrub = function(
-  X, projection=c("ICA", "PCA"), 
+  X, projection=c(
+    "ICA", 
+    #"fusedPCA", 
+    "PCA"
+  ), 
   nuisance="DCT4",
   center=TRUE, scale=TRUE, comps_mean_dt=FALSE, comps_var_dt=FALSE,
   PESEL=TRUE, kurt_quantile=.99, 
+  #fusedPCA_kwargs=NULL, 
   get_dirs=FALSE, full_PCA=FALSE,
   get_outliers=TRUE, cutoff=4, seed=0,
   verbose=FALSE){
   
-  projection <- match.arg(projection, c("ICA", "PCA"))
+  projection <- match.arg(projection, c(
+    "ICA", 
+    #"fusedPCA", 
+    "PCA"
+  ))
   if (!PESEL) { projection <- paste0(projection, "2") }
   if (kurt_quantile > 0) { 
     projection <- paste0(projection, "_kurt")
@@ -108,6 +118,7 @@ pscrub = function(
     nuisance=nuisance,
     center=center, scale=scale, comps_mean_dt=comps_mean_dt, comps_var_dt=comps_var_dt,
     kurt_quantile=kurt_quantile, 
+    #fusedPCA_kwargs=fusedPCA_kwargs,
     get_dirs=get_dirs, full_PCA=full_PCA,
     get_outliers=get_outliers, cutoff=cutoff, seed=seed,
     verbose=verbose
