@@ -1,7 +1,7 @@
 test_that("pscrub works", {
   psx <- testthat::expect_warning(fMRIscrub:::pscrub_multi(
     Dat1,
-    projection = c("ICA", "ICA_kurt"), # "all"
+    projection = "all"
   ))
   myplot <- fMRIscrub:::plot.scrub_projection_multi(psx)
 
@@ -18,7 +18,7 @@ test_that("pscrub works", {
   plot(psx)
 
   # psx <- pscrub(
-  #   matrix(rnorm(4000), nrow=30), "fusedPCA", 1, center=FALSE, PESEL=FALSE, kurt_quantile=.8,
+  #   matrix(rnorm(9000), nrow=30), "fusedPCA", 1, center=FALSE, PESEL=FALSE, kurt_quantile=.8,
   #   full_PCA = TRUE, cutoff=5, verbose=TRUE
   # )
   # plot(psx)
@@ -28,11 +28,11 @@ test_that("pscrub works", {
   ))
 
   psx <- testthat::expect_warning(pscrub(
-    matrix(rnorm(10000), nrow=100) + 100, nuisance=dct_bases(100, 2)
+    matrix(rnorm(10000), nrow=100) + 100, nuisance=fMRItools::dct_bases(100, 2)
   ))
 
   psx <- testthat::expect_warning(pscrub(
-    Dat2, projection="PCA", nuisance=cbind(1, dct_bases(nrow(Dat2), 12)),
+    Dat2, projection="PCA", nuisance=cbind(1, fMRItools::dct_bases(nrow(Dat2), 12)),
     comps_mean_dt=2, comps_var_dt=2, get_dirs=TRUE, get_outliers=FALSE
   ))
   plot(psx)
