@@ -1,14 +1,16 @@
 test_that("pscrub works", {
   psx <- testthat::expect_warning(fMRIscrub:::pscrub_multi(
     Dat1,
-    projection = c("ICA", "ICA_kurt"), # "all"
+    projection = "all"
   ))
-  fMRIscrub:::plot.scrub_projection_multi(psx)
+  fMRIscrub:::plot.scrub_projection_multi(psx) # expect_warning w/ fusedPCA?
 
-  # fusedPCA
   psx <- testthat::expect_warning(fMRIscrub:::pscrub_multi(
     Dat2,
-    projection = c("PCA", "ICA_kurt"),
+    projection = c(
+      #"fusedPCA",
+      "ICA_kurt"
+    ),
     kurt_quantile = .90,
     cutoff = 5,
     verbose = TRUE
@@ -29,14 +31,14 @@ test_that("pscrub works", {
   ))
 
   psx <- testthat::expect_warning(pscrub(
-    matrix(rnorm(10000), nrow=100) + 100, nuisance=dct_bases(100, 2)
+    matrix(rnorm(10000), nrow=100) + 100, nuisance=fMRItools::dct_bases(100, 2)
   ))
-  plot(psx)
 
   # psx <- testthat::expect_warning(pscrub(
-  #   Dat2, projection="fusedPCA", nuisance=cbind(1, dct_bases(nrow(Dat2), 12)),
+  #   Dat2, projection="fusedPCA", nuisance=cbind(1, fMRItools::dct_bases(nrow(Dat2), 12)),
   #   comps_mean_dt=2, comps_var_dt=2, get_dirs=TRUE, get_outliers=FALSE
   # ))
+  # plot(psx)
 })
 
 test_that("DVARS works", {
@@ -71,5 +73,5 @@ test_that("ciftiTools-related functions work", {
 })
 
 test_that("Miscellaneous functions work", {
-  testthat::expect_warning(summary(pscrub(fsl_bptf(Dat2))))
+  testthat::expect_warning(summary(pscrub(fMRItools::fsl_bptf(Dat2))))
 })
